@@ -17,13 +17,18 @@ Audio::Audio(QObject *parent) :
 
 void Audio::createWav(QString filename)
 {
-
+    reader = new Reader();
+    connect(reader, SIGNAL(finished()), this, SLOT(threadFinished()));
 
     QString audio = filename;
     audio.chop(3);
     audio.append("wav");
     audioFile = new QFile(audio);
-    if (!audioFile->open(QIODevice::ReadWrite))
+
+    reader->setFileName(filename);
+
+    reader->start();
+   /* if (!audioFile->open(QIODevice::ReadWrite))
         qDebug()<<"cannot write to file";
     else
     {
@@ -39,15 +44,24 @@ void Audio::createWav(QString filename)
         myProcess->start(program, arguments);
         myProcess->waitForFinished();
 
-        music = Phonon::createPlayer(Phonon::MusicCategory,
-                                      Phonon::MediaSource(audioFile->fileName()));
 
 
-        connect(music, SIGNAL(finished()), this, SLOT(audioFinished()));
+    }*/
 
-        audioFile->close();
-        this->wavCreated();
-    }
+}
+
+void Audio::threadFinished()
+{
+    music = Phonon::createPlayer(Phonon::MusicCategory,
+                                  Phonon::MediaSource(audioFile->fileName()));
+
+
+    connect(music, SIGNAL(finished()), this, SLOT(audioFinished()));
+
+    audioFile->close();
+
+    reader->deleteLater();
+    this->wavCreated();
 
 }
 
